/*  Copyright (C) 2013 Ben Asselstine

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 3 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
  02110-1301, USA.
*/
#ifndef LU_COMMENT_STYLE_H
#define LU_COMMENT_STYLE_H 1

#include <config.h>
#include <stdio.h>
#include <argp.h>
struct lu_comment_style_t
{
  const char *name;
  const struct argp *argp;
  int (*get_initial_comment) (char *file, char **argz, size_t *len, char **hash, int full, int *sr, int *sc, int *dr, int *dc);
  char* (*comment) (char *text);
  void (*uncomment) (char **argz, size_t *argz_len, int trim);
  int multiline;
  char *support_file_exts;
  char *avoid_file_exts;
};

#endif
